summaryrefslogtreecommitdiffstats
path: root/kpovmodeler/pmmovecommand.h
diff options
context:
space:
mode:
Diffstat (limited to 'kpovmodeler/pmmovecommand.h')
-rw-r--r--kpovmodeler/pmmovecommand.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/kpovmodeler/pmmovecommand.h b/kpovmodeler/pmmovecommand.h
index 188d721c..934f7fa4 100644
--- a/kpovmodeler/pmmovecommand.h
+++ b/kpovmodeler/pmmovecommand.h
@@ -39,23 +39,23 @@ public:
/**
* Command that moves one PMObject.
*
* The object obj will be inserted as child of tqparent after
* the object after.
*
* If after is 0, the object becomes the first child.
*/
- PMMoveCommand( PMObject* obj, PMObject* tqparent, PMObject* after );
+ PMMoveCommand( PMObject* obj, PMObject* parent, PMObject* after );
/**
* Command that moves a list of new PMObjects.
* The objects don't have to be siblings of each other.
*
* The object in the list will be inserted as tqchildren of tqparent after
* the object after.
*
* If after is 0, the objects will be inserted as first tqchildren.
*/
- PMMoveCommand( const PMObjectList& list, PMObject* tqparent, PMObject* after );
+ PMMoveCommand( const PMObjectList& list, PMObject* parent, PMObject* after );
/**
* Deletes the command.
*/
@@ -39,23 +39,23 @@ public:
* Command that moves one PMObject.
*
- * The object obj will be inserted as child of tqparent after
+ * The object obj will be inserted as child of parent after
* the object after.
*
@@ -39,23 +39,23 @@ public:
* The objects don't have to be siblings of each other.
*
- * The object in the list will be inserted as tqchildren of tqparent after
+ * The object in the list will be inserted as tqchildren of parent after
* the object after.
*